//
//  TCGBConfiguration.h
//  Gamebase
//
//  Created by NHNENT on 2016. 12. 28..
//  Copyright © 2016년 NHN Entertainment Corp. All rights reserved.
//

#import <Foundation/Foundation.h>

extern NSString* const kConfigurationShowBlockingPopup;

/** TCGBConfiguration configures essential Gamebase settings.
 */
@interface TCGBConfiguration : NSObject

/**---------------------------------------------------------------------------------------
 * @name Properties
 *  ---------------------------------------------------------------------------------------
 */

/**
 ApplicationID which is Toast Cloud Project ID.
 */
@property (nonatomic, strong) NSString* appID;

/**
 Application Version that is registered at Toast Cloud Console.
 */
@property (nonatomic, strong) NSString* appVersion;

/**
 Zone Type that is nomally "REAL".
 */
@property (nonatomic, strong) NSString* zoneType;

/**
 Server Address which your application communicates with.
 */
@property (nonatomic, strong, readonly) NSURL*    serverAddress;

/**
 Extra Options such as whether Showing Blocking PopUp enabled or not.
 */
@property (nonatomic, strong)           NSMutableDictionary*     options;

/**---------------------------------------------------------------------------------------
 * @name Initialization
 *  ---------------------------------------------------------------------------------------
 */

/**
 Creates TCGBConfiguration instance
 
 @param appID ApplicationID which is Toast Cloud Project ID.
 @param appVersion Application Version that is registered at Toast Cloud Console.
 */
+ (TCGBConfiguration *)configurationWithAppID:(NSString *)appID appVersion:(NSString *)appVersion;

/**
 Creates TCGBConfiguration instance
 
 @param appID ApplicationID which is Toast Cloud Project ID.
 @param appVersion Application Version that is registered at Toast Cloud Console.
 @param zoneType Zone Type that is nomally "REAL". It is only used to ToastCloud Beta/Alaha Test.
 */
+ (TCGBConfiguration *)configurationWithAppID:(NSString *)appID appVersion:(NSString *)appVersion zoneType:(NSString *)zoneType;

/**---------------------------------------------------------------------------------------
 * @name Setting Options
 *  ---------------------------------------------------------------------------------------
 */

/**
 Enable Show Blocking PopUp.
 
 @param isShow `YES` if Shown Popup blocking another processes.
 */
- (void)setShowBlockingPopup:(BOOL)isShow;

@end
