//
//  TCGBLaunching.h
//  Gamebase
//
//  Created by NHNENT on 2016. 6. 27..
//  Copyright © 2016년 NHN Entertainment Corp. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "TCGBError.h"

#ifndef TCGBLaunching_h
#define TCGBLaunching_h

/// JSONPath for Launching Informations

typedef NS_ENUM(NSUInteger, TCGBLaunchingStatus) {
    NORMAL = 200,
    RECOMMAND_UPDATE = 201,
    NORMAL_BY_QA_WHITELIST = 202,           
    
    REQUIRE_UPDATE = 300,
    BLOCK_BY_BLACKLIST = 301,
    TERMINATED_SERVICE = 302,
    INSPECTING_SERVICE = 303,               // 상태 및 Raw Data를 모두 넘겨줄 수 있을 경우
    INSPECTION_SERVICE_ALLSERVICES = 304,   // 상태만 넘겨줄 수 있을 경우
    
    UNREGISTERED_GAME = 400,
    UNREGISTERED_CLIENT = 401,
    
    INTERNAL_SERVER_ERROR = 500,
};

// launching정보에서 statuscode가 변경되었을 때만 Noti해줌.
extern NSString* const kTCGBLaunchingStatusCodeChangedNotification;

typedef void(^launchingCompletion)(id launchingData, TCGBError *error);
typedef void(^changedStatusNotificationHandler)(NSDictionary *launchingStatus);


@class TCGBWebSocket;

/** The TCGBLaunching class contains several informations that is received from the server after application is successfully launched.
 */
@interface TCGBLaunching : NSObject
{
    __weak TCGBWebSocket*        _webSocket;
    NSMutableArray*             _statusNotificationHandlers;
    NSDictionary*               _launchingStatusData;
    NSDate*                     _dateOfLastUpdatedStatus;
    TCGBLaunchingStatus          _launchingStatus;
    
    BOOL                        _registeredScheduleForStatus;
    NSTimer*                    _refreshTimer;
    launchingCompletion         _completionHandler;
    
    NSDictionary*               _launchingInformations;
    NSDictionary*               _TCGBLaunchingInformations;
    NSArray*                    _TCIAPInformations;
    NSDictionary*               _TCLaunchingInformations;
    NSDictionary*               _TCProductInformations;
    
    /**
     Last Checked Notification Time. Notification could be set in the Toast Cloud Console.
     */
    NSNumber*                   _lastLCNT;
}

/**---------------------------------------------------------------------------------------
 * @name Launching Information
 *  ---------------------------------------------------------------------------------------
 */

/**
 @return Launching Status which indicates whether the application is playable or not.
 @see TCGBLaunchingStatus
 */
+ (TCGBLaunchingStatus)launchingStatus;

/**
 @return All Launching Information from the server.
 */
+ (NSDictionary *)launchingInformations;

/**
 @return Launching Information related with TCGB launching service.
 */
+ (NSDictionary *)TCGBLaunchingInformations;

/**
 @return Launching Information related with toast cloud product.
 */
+ (NSDictionary *)tcProductInformations;

/**
 @return Launching Information related with toast cloud launching.
 */
+ (NSDictionary *)tcLaunchingInformations;

/**
 @return Launching Information related with toast cloud IAP.
 */
+ (NSArray *)tcIAPInformations;

/**
 @param notificationHandler When launching status is changed, this notificationHandler is called.
 */
+ (void)addUpdateStatusNotification:(changedStatusNotificationHandler)notificationHandler;

/**
 @param notificationHandler notificationHandler which would be removed.
 */
+ (void)removeUpdateStatusNotification:(changedStatusNotificationHandler)notificationHandler;

@end

#endif // TCGBLaunching_h
