//
//  TCGBConfig.h
//  Gamebase
//
//  Created by NHNENT on 2016. 12. 16..
//  Copyright © 2016년 NHN Entertainment Corp. All rights reserved.
//

#import <Foundation/Foundation.h>

#ifndef TCGBLOCALCONFIGURATION_H
#define TCGBLOCALCONFIGURATION_H

extern NSString* const kGamebaseBundleFilename;
// config.plist keyname
extern NSString* const kConfigSDKVersion;
extern NSString* const kConfigServerAPIVersion;
extern NSString* const kConfigServerAddresses;
extern NSString* const kConfigServerAddressesDev;
extern NSString* const kConfigServerAddressesAlpha;
extern NSString* const kConfigServerAddressesReal;
extern NSString* const kConfigPushServerAddress;
extern NSString* const kConfigWebsocketTimeout;
extern NSString* const kConfigWebsocketReadTimeout;
extern NSString* const kConfigWebsocketMaxRetryCount;
extern NSString* const kConfigWebsocketRetryInterval;
extern NSString* const kConfigHeartbeatInterval;
extern NSString* const kConfigLaunchingSchedule;
extern NSString* const kConfigLaunchingExpireTime;
extern NSString* const kConfigStoreCode;

/** TCGBLocalConfiguration has several information that is in the config.plist in Gamebase.bundle.
 */
@interface TCGBLocalConfiguration : NSObject

/**---------------------------------------------------------------------------------------
 * @name Properties
 *  ---------------------------------------------------------------------------------------
 */

/**
 Information which is in config.plist.
 */
@property (nonatomic, strong) NSMutableDictionary* configuration;

/**---------------------------------------------------------------------------------------
 * @name Initialization
 *  ---------------------------------------------------------------------------------------
 */

/**
 Obtain a singleton instance.
 */
+ (TCGBLocalConfiguration *)sharedConfig;

/**---------------------------------------------------------------------------------------
 * @name Configuration
 *  ---------------------------------------------------------------------------------------
 */

/**
 SDK Version
 */
- (NSString *)SDKVersion;

/**
 Server API Version
 */
- (NSString *)ServerAPIVersion;

/**
 Server URL with zone type.
 
 @param zone Zone should be one of the REAL, BETA and ALPHA. (case insensitive)
 */
- (NSString *)serverURLWithZone:(NSString *)zone;

/**
 Server URLs which are in the config.plist.
 */
- (NSDictionary *)serverURLs;

/**
 Push Server URL with zone type.
 
 @param zone Zone should be one of the REAL, BETA and ALPHA. (case insensitive)
 */
- (NSString *)pushServerURLWithZone:(NSString *)zone;

/**
 WebSocket Timeout Interval in seconds.
 */
- (NSInteger)webSocketTimeout;

/**
 WebSocket Read Timeout Interval in seconds.
 */
- (NSTimeInterval)webSocketReadTimeout;

/**
 Maximum Retry Count for Connecting with Web Socket.
 */
- (NSInteger)webSocketMaxRetryCount;

/**
 Retry Interval for Retrying with Web Socket.
 */
- (NSTimeInterval)webSocketRetryInterval;

/**
 HeartBeat Interval
 */
- (NSInteger)heartbeatInterval;

/**
 Interval for Scheduling Launching Status
 */
- (NSInteger)launchingSchedule;

/**
 Expiry Time for Scheduling Launching Status
 */
- (NSInteger)launchingExpireTime;

/**
 Store Code, actually AS.
 */
- (NSString *)storeCode;

@end

#endif
