//
//  TCGBWebBrowser.h
//  TCGBWebKit
//
//  Created by Park Panki on 2016. 12. 20..
//  Copyright © 2016년 NHN Entertainment. All rights reserved.
//

#import <UIKit/UIKit.h>

@class TCGBWebURL;
@class TCGBWebConfiguration;
@class TCGBWebViewController;

extern NSString * const kTCGBWebKitDomain;
extern NSString * const kTCGBWebKitBundleName;

/** The TCGBWebBrowser class represents the entry point for **launching WebView**.
 */
@interface TCGBWebBrowser : NSObject

/**---------------------------------------------------------------------------------------
 * @name Properties
 *  ---------------------------------------------------------------------------------------
 */

/**

This property is a global configuration for launching webview.<br/>
When you handle the webview without any configuration, TCGBWebBrowser set its configuration with this value.
*/
@property (nonatomic, strong) TCGBWebConfiguration *defaultWebConfiguration;

/**
 
 This dictionary contains key-action objectes.<br/>
 Each key represents custom scheme, and each action is completionHandler.
 @see addCustomScheme:block:
 @see removeCustomScheme:
 */
@property (nonatomic, strong) NSMutableDictionary *schemeCallbackDictionary;

/**---------------------------------------------------------------------------------------
 * @name Initialization
 *  ---------------------------------------------------------------------------------------
 */

/**
 
 Creates and returns an `TCGBWebBrowser` object.
 */
+ (instancetype)sharedTCGBWebBrowser;


/**---------------------------------------------------------------------------------------
 * @name Launching WebView
 *  ---------------------------------------------------------------------------------------
 */

/**
 Launching WebView that is not for local url.
 
 @param urlString The string value for target url
 @param viewController The presenting view controller
 @warning If viewController is nil, TCGBWebBrowser set it to top most view controller automatically.
 @param configuration This configuration is applied to the behavior of webview.
 @warning If configuration is nil, TCGBWebBrowser set it to default value. It is described in `TCGBWebConfiguration`.
 */
+ (void)launchWebViewWithURL:(NSString *)urlString viewController:(UIViewController*)viewController configuration:(TCGBWebConfiguration *)configuration;

/**
 Launching WebView for local html (or other resources)
 
 @param filePath The string value for target local path.
 @param bundle Where the file is located.
 @warning If bundle is nil, TCGBWebBrowser set it to main bundle automatically.
 @param viewController The presenting view controller
 @warning If viewController is nil, TCGBWebBrowser set it to top most view controller automatically.
 @param configuration This configuration is applied to the behavior of webview.
 @warning If configuration is nil, TCGBWebBrowser set it to default value. It is described in `TCGBWebConfiguration`.
 */
+ (void)launcheWebViewWithLocalURL:(NSString *)filePath bundle:(NSBundle *)bundle viewController:(UIViewController*)viewController configuration:(TCGBWebConfiguration *)configuration;


/**---------------------------------------------------------------------------------------
 * @name Managing Custom Scheme
 *  ---------------------------------------------------------------------------------------
 */

/**
 Add Custom Scheme
 
 @param schemeString This string is the key that is called in html or the other place.
 @param handler This handler is a block which will be excuted by calling the schemeString, the key.
 */
+ (void)addCustomScheme:(NSString *)schemeString block:(void(^)(TCGBWebViewController *TCGBWebViewController, TCGBWebURL *webURL))handler;

/**
 Remove Custom Scheme
 
 @param schemeString This string is the key of `schemeCallbackDictionary`.
 */
+ (void)removeCustomScheme:(NSString *)schemeString;

@end
