//
//  TCGBWebViewController.h
//  TCGBWebKit
//
//  Created by Park Panki on 2016. 12. 20..
//  Copyright © 2016년 NHN Entertainment. All rights reserved.
//

#import <UIKit/UIKit.h>

@class TCGBWebConfiguration;

extern NSInteger kTCGBWebHeaderViewPaddingBottom;
extern NSInteger kTCGBWebHeaderViewHeight;
extern NSInteger kTCGBWebNavigationBarHeight;

/** The TCGBWebViewController is a view controller class which have webview, headerview, maskview and etc.
 */
@interface TCGBWebViewController : UIViewController <UIWebViewDelegate, UINavigationBarDelegate>

/**---------------------------------------------------------------------------------------
 * @name Properties
 *  ---------------------------------------------------------------------------------------
 */

/**
 Mask View.
 
 Only used in popup launch style.
 */
@property (nonatomic, strong) UIView *maskView;

/**
 Header View.
 
 Only used in popup launch style.
 */
@property (nonatomic, strong) UIView *headerView;

/**
 Web View.
 
 You can handle this webView through custom scheme.
 @see [TCGBWebBrowser addCustomScheme]
     
    [TCGBWebBrowser addCustomScheme:@"gamebase://getUserInformation" block:^(TCGBWebViewController *browserController, TCGBWebURL *webURL) {
         NSLog(@"%@ 호출!", webURL.host);
         
         NSString *userID = [TCGBGamebase userID];
         NSString *registeredDate = @"-";
         NSArray *authList = [TCGBGamebase authMappingList];
         NSString *authListString = [authList componentsJoinedByString:@", "];
         
         NSMutableString *javascript = [[NSMutableString alloc] init];
         __block NSMutableString *params = [[NSMutableString alloc] init];
         __block NSMutableString *callback = [[NSMutableString alloc] init];
         [webURL.query enumerateKeysAndObjectsUsingBlock:^(id  _Nonnull key, id  _Nonnull obj, BOOL * _Nonnull stop) {
         if ([key caseInsensitiveCompare:@"callback"] == NSOrderedSame) {
         callback = obj;
         }
         }];
         
         [params appendFormat:@"'%@',", userID];
         [params appendFormat:@"'%@',", registeredDate];
         [params appendFormat:@"'%@',", authListString];
         
         [javascript appendFormat:@"javascript:%@(%@)", callback, params];
         [browserController.theWebView stringByEvaluatingJavaScriptFromString:javascript];
     }];
 */
@property (nonatomic, strong) UIWebView *theWebView;

/**
 Navigatino Bar.
 
 Only used in full screen launch style.
 */
@property (nonatomic, strong) UINavigationBar *navBar;

/**
 WebView Configuration.
 
 You can handle the webview with this configuration property.
 */
@property (nonatomic, strong) TCGBWebConfiguration *configuration;

/**
 UIViewController Delegate.
 
 It is used to delegate UIViewController's methods such as viewDidLoad: viewWillLoad: viewDidDisappear: and etc.
 It is setted by configuration property.
 */
@property (nonatomic, strong) UIViewController *delegate;


/**---------------------------------------------------------------------------------------
 * @name Initialization
 *  ---------------------------------------------------------------------------------------
 */

/**
 Initialization with TCGBWebConfiguration.
 
 @param configuration With this property, TCGBWebViewController initialize its components such as webview, orientation, launch style and so on.
 */
- (instancetype)initWithConfiguration:(TCGBWebConfiguration *)configuration;

/**---------------------------------------------------------------------------------------
 * @name Launching
 *  ---------------------------------------------------------------------------------------
 */

/**
 Launching WebView that is not for local url.
 
 @param urlString The string value for target url
 @param viewController The presenting view controller
 */
- (void)launcheWebViewWithURL:(NSString *)urlString viewController:(UIViewController *)viewController;

/**
 Launching WebView for local html (or other resources)
 
 @param localFilePath The string value for target local path.
 @param bundle Where the file is located.
 @param viewController The presenting view controller
 */
- (void)launcheWebViewWithLocalURL:(NSString *)localFilePath bundle:(NSBundle *)bundle viewController:(UIViewController *)viewController;


#pragma mark - UIWebViewDelegate
/**---------------------------------------------------------------------------------------
 * @name WebView Delegate
 *  ---------------------------------------------------------------------------------------
 */

//- (BOOL)webView:(UIWebView *)webView shouldStartLoadWithRequest:(NSURLRequest *)request navigationType:(UIWebViewNavigationType)navigationType;
//- (void)webViewDidStartLoad:(UIWebView *)webView;
//- (void)webViewDidFinishLoad:(UIWebView *)webView;
//- (void)webView:(UIWebView *)webView didFailLoadWithError:(NSError *)error;


#pragma mark - WebView Close and GoBack
/**---------------------------------------------------------------------------------------
 * @name WebView Delegate
 *  ---------------------------------------------------------------------------------------
 */

/**
 Go Back Button pressed.
 
 */
- (void)goBackButtonPressed;

/**
 Close Button Pressed.
 
 Only used in full screen launch style.
 */
- (void)closeButtonPressed;

@end
